`print.micro` <-
function(x, ...){
  cat(paste("\n Object created with method", x$method))
  cat("\n -------------------------\n")
  cat("Try names(your object from class micro) for more details")
  cat("\n")
}

